@@ -38,6 +38,7 @@ from processor.connector.snapshot_azure import populate_azure_snapshot
 from processor.connector.snapshot_custom import populate_custom_snapshot, get_custom_data
 from processor.connector.snapshot_aws import populate_aws_snapshot
 from processor.connector.snapshot_google import populate_google_snapshot
+from processor.connector.snapshot_kubernetes import populate_kubernetes_snapshot
 from processor.connector.populate_json import pull_json_data
 from processor.helper.file.file_utils import exists_file,remove_file
 
@@ -48,7 +49,8 @@ mastersnapshot_fns = {
     'azure': populate_azure_snapshot,
     'filesystem': populate_custom_snapshot,
     'aws': populate_aws_snapshot,
-    'google' : populate_google_snapshot
+    'google' : populate_google_snapshot,
+    'kubernetes': populate_kubernetes_snapshot
 }
 
 
